@@ -1,4 +1,4 @@
-/* $Id: init.c,v 1.8 2000/10/20 01:21:34 trow Exp $ */
+/* $Id: init.c,v 1.10 2001/05/06 08:26:28 trow Exp $ */
 
 /*
  * init.c
@@ -30,12 +30,12 @@
 #include "guppi-scatter-state.h"
 #include "guppi-scm-scatter.h"
 #ifdef HAVE_PYTHON
-#include "guppi-python-scatter.h"
+void guppi_python_scatter_init (void);
 #endif
 
 GuppiPlugIn *guppi_plug_in (void);
 
-/***************************************************************************/
+/*************************************************************************/
 
 static GuppiElementState *
 make_element (void)
@@ -68,4 +68,4 @@ guppi_plug_in (void)
 }
 
 
-/* $Id: init.c,v 1.8 2000/10/20 01:21:34 trow Exp $ */
+/* $Id: init.c,v 1.10 2001/05/06 08:26:28 trow Exp $ */
