@@ -1,9 +1,10 @@
-/* $Id: guppi-marker.c,v 1.8 2001/01/16 23:36:28 trow Exp $ */
+/* $Id: guppi-marker.c,v 1.13 2001/10/02 02:10:18 trow Exp $ */
 
 /*
  * guppi-marker.c
  *
  * Copyright (C) 2000 EMC Capital Management, Inc.
+ * Copyright (C) 2001 The Free Software Foundation
  *
  * Developed by Jon Trowbridge <trow@gnu.org>.
  *
@@ -24,6 +25,7 @@
  */
 
 #include <config.h>
+#include "guppi-marker.h"
 
 #include <libgnome/gnome-defs.h>
 #include <libgnome/gnome-config.h>
@@ -32,7 +34,7 @@
 #include <math.h>
 #include <ctype.h>
 #include <guppi-metrics.h>
-#include "guppi-marker.h"
+
 
 typedef struct _GuppiMarkerInfoPrivate GuppiMarkerInfoPrivate;
 
@@ -44,9 +46,9 @@ struct _GuppiMarkerInfoPrivate {
 		 double sz1, double sz2);
 };
 
-/****************************************************************************/
+/**************************************************************************/
 
-/*** Marker Alpha Template Constructors ***/
+/*** Marker Alpha Template Constructors */
 
 static GuppiAlphaTemplate *
 template_circle (double r, double w)
@@ -102,6 +104,33 @@ template_ast (double r, double w)
   return guppi_alpha_template_new_ast (r, w, 0);
 }
 
+static GuppiAlphaTemplate *
+template_triangle (double r, double w)
+{
+  r = guppi_pt2px (r);
+  w = guppi_pt2px (w);
+
+  return guppi_alpha_template_new_triangle (r, w, 0);
+}
+
+static GuppiAlphaTemplate *
+template_bar (double r, double w)
+{
+  r = guppi_pt2px (r);
+  w = guppi_pt2px (w);
+
+  return guppi_alpha_template_new_bar (r, r, w, 0);
+}
+
+static GuppiAlphaTemplate *
+template_half_bar (double r, double w)
+{
+  r = guppi_pt2px (r);
+  w = guppi_pt2px (w);
+
+  return guppi_alpha_template_new_bar (r, 0, w, 0);
+}
+
 #if 0
 static GuppiAlphaTemplate *
 template_pixel (double sz1, double sz2)
@@ -139,9 +168,16 @@ template_filled_diamond (double r, double unused)
   return guppi_alpha_template_new_box (r, M_PI / 4);
 }
 
-/****************************************************************************/
+static GuppiAlphaTemplate *
+template_filled_triangle (double r, double unused)
+{
+  r = guppi_pt2px (r);
+  return guppi_alpha_template_new_filled_triangle (r, 0);
+}
 
-/*** Marker Print Routines ***/
+/**************************************************************************/
+
+/*** Marker Print Routines */
 
 static void
 generic_print_circle (GuppiElementPrint * ep,
@@ -278,6 +314,59 @@ generic_print_square (GuppiElementPrint * ep,
   }
 }
 
+static void
+generic_print_triangle (GuppiElementPrint * ep,
+			double x, double y,
+			double sz, double w,
+			gboolean filled,
+			guint32 fill_color, guint32 edge_color)
+{
+  gint j;
+  g_return_if_fail (ep != NULL);
+  g_return_if_fail (GUPPI_IS_ELEMENT_PRINT (ep));
+
+  for (j = 0; j < 2; ++j) {
+
+    if ((j == 0 && filled) || (j == 1 && w > 0)) {
+
+      guppi_element_print_newpath (ep);
+      guppi_element_print_moveto (ep, x - sz, y - sz);
+      guppi_element_print_lineto (ep, x, y + sz);
+      guppi_element_print_lineto (ep, x + sz, y - sz);
+      guppi_element_print_closepath (ep);
+
+      if (j == 0 && filled) {
+
+	if (fill_color != 0)
+	  guppi_element_print_setrgbacolor_uint (ep, fill_color);
+	guppi_element_print_fill (ep);
+
+      } else if (j == 1 && w > 0) {
+
+	guppi_element_print_setlinewidth (ep, w);
+	guppi_element_print_stroke (ep);
+
+      }
+    }
+  }
+}
+
+static void
+generic_print_bar (GuppiElementPrint * ep,
+		   double x, double y,
+		   double sz, gboolean half,
+		   guint32 edge_color)
+{
+  g_return_if_fail (ep != NULL);
+  g_return_if_fail (GUPPI_IS_ELEMENT_PRINT (ep));
+
+  guppi_element_print_newpath (ep);
+  guppi_element_print_moveto (ep, half ? x : x - sz, y);
+  guppi_element_print_lineto (ep, x + sz, y);
+  guppi_element_print_closepath (ep);
+  guppi_element_print_stroke (ep);
+}
+
 static void
 print_circle (GuppiElementPrint * ep, double x, double y, double r, double w)
 {
@@ -354,6 +443,27 @@ print_ast (GuppiElementPrint * ep, double x, double y, double sz, double w)
   guppi_element_print_stroke (ep);
 }
 
+static void
+print_triangle (GuppiElementPrint * ep, double x, double y,
+		double sz, double unused)
+{
+  generic_print_triangle (ep, x, y, sz, 0, FALSE, 0, 0);
+}
+
+static void
+print_bar (GuppiElementPrint * ep, double x, double y,
+	   double sz, double unused)
+{
+  generic_print_bar (ep, x, y, sz, FALSE, 0);
+}
+
+static void
+print_half_bar (GuppiElementPrint * ep, double x, double y,
+		double sz, double unused)
+{
+  generic_print_bar (ep, x, y, sz, TRUE, 0);
+}
+
 #if 0
 static void
 print_pixel (GuppiElementPrint * ep, double x, double y,
@@ -391,7 +501,14 @@ print_filled_diamond (GuppiElementPrint * ep, double x, double y,
   generic_print_diamond (ep, x, y, sz, 0, TRUE, 0, 0);
 }
 
-/****************************************************************************/
+static void
+print_filled_triangle (GuppiElementPrint * ep, double x, double y,
+		      double sz, double unused)
+{
+  generic_print_triangle (ep, x, y, sz, 0, TRUE, 0, 0);
+}
+
+/**************************************************************************/
 
 static GuppiMarkerInfoPrivate guppi_marker_info_array[] = {
 
@@ -436,6 +553,24 @@ static GuppiMarkerInfoPrivate guppi_marker_info_array[] = {
    template_ast,
    print_ast},
 
+  {{GUPPI_MARKER_TRIANGLE, "triangle", N_("Triangle"),
+    N_("Radius"), 1, 15, 4,
+    NULL, 0.5, 12, 1},
+   template_triangle,
+   print_triangle},
+
+  {{GUPPI_MARKER_BAR, "bar", N_("Bar"),
+    N_("Length"), 1, 15, 4,
+    NULL, 0.5, 12, 1},
+   template_bar,
+   print_bar},
+
+  {{GUPPI_MARKER_HALF_BAR, "half bar", N_("Half Bar"),
+    N_("Length"), 1, 15, 4,
+    NULL, 0.5, 12, 1},
+   template_half_bar,
+   print_half_bar},
+
 #if 0
   {{GUPPI_MARKER_PIXEL, N_("Pixel"),
     NULL, 0, 0, 0,
@@ -466,7 +601,13 @@ static GuppiMarkerInfoPrivate guppi_marker_info_array[] = {
     N_("Radius"), 1, 15, 4,
     NULL, 0.5, 12, 1},
    template_filled_diamond,
-   print_filled_diamond}
+   print_filled_diamond},
+
+  {{GUPPI_MARKER_FILLED_TRIANGLE, "filled triangle", N_("Filled Triangle"),
+    N_("Radius"), 1, 15, 4,
+    NULL, 0.5, 12, 1},
+   template_filled_triangle,
+   print_filled_triangle}
 };
 
 static gboolean
@@ -606,4 +747,4 @@ guppi_marker_print (GuppiMarker m,
 
 
 
-/* $Id: guppi-marker.c,v 1.8 2001/01/16 23:36:28 trow Exp $ */
+/* $Id: guppi-marker.c,v 1.13 2001/10/02 02:10:18 trow Exp $ */
