@@ -1,10 +1,11 @@
 /* This is -*- C -*- */
-/* $Id: guppi-plot-toolkit.h,v 1.11 2000/12/16 03:42:50 trow Exp $ */
+/* $Id: guppi-plot-toolkit.h,v 1.13 2001/09/08 05:49:58 trow Exp $ */
 
 /*
  * guppi-plot-toolkit.h
  *
  * Copyright (C) 2000 EMC Capital Management, Inc.
+ * Copyright (C) 2001 The Free Software Foundation
  *
  * Developed by Jon Trowbridge <trow@gnu.org> and
  * Havoc Pennington <hp@pobox.com>.
@@ -28,7 +29,8 @@
 #ifndef _INC_GUPPI_PLOT_TOOLKIT_H
 #define _INC_GUPPI_PLOT_TOOLKIT_H
 
-#include <gnome.h>
+/* #include <gnome.h> */
+#include <gtk/gtktoolbar.h>
 
 #include "guppi-plot-tool.h"
 
@@ -121,4 +123,4 @@ END_GUPPI_DECLS
 
 #endif /* _INC_GUPPI_PLOT_TOOLKIT_H */
 
-/* $Id: guppi-plot-toolkit.h,v 1.11 2000/12/16 03:42:50 trow Exp $ */
+/* $Id: guppi-plot-toolkit.h,v 1.13 2001/09/08 05:49:58 trow Exp $ */
