@@ -1,4 +1,4 @@
-/* $Id: guppi-python.c,v 1.16 2001/01/20 18:59:21 trow Exp $ */
+/* $Id: guppi-python.c,v 1.21 2001/09/08 05:50:00 trow Exp $ */
 
 /*
  * guppi-python.c
@@ -26,20 +26,21 @@
  * Place, Suite 330, Boston, MA 02111-1307 USA
  */
 
+#define IN_GUPPI_PYTHON_C
+#include <config.h>
+#include "guppi-python.h"
+
 #include <stdio.h>
 #include <string.h>
-#include <config.h>
+
 /* #include <gnome.h> */
 #include <libgnome/gnome-defs.h>
 #include <libgnome/gnome-config.h>
 #include <libgnome/gnome-i18n.h>
 
-#define IN_GUPPI_PYTHON_C
 #include <Python.h>
-#include "guppi-python.h"
 
 #include "guppi-memory.h"
-#include "guppi-splash.h"
 #include "guppi-rgb.h"
 #include "guppi-plug-in-spec.h"
 
@@ -113,7 +114,9 @@ guppi_python_init (void)
   g_return_if_fail (init == FALSE);
   init = TRUE;
 
+#if 0
   guppi_splash_message (_("Initializing"), _("Python"));
+#endif
 
 #ifdef BROKEN_PY_INITIALIZE
   /* Python's convertenviron has gotten into its head that it can
@@ -1031,7 +1034,7 @@ static PyMethodDef _guppimoduleMethods[] = {
 
 static
   void
-guppi_python_module_init ()
+guppi_python_module_init (void)
 {
   PyObject *m, *d, *private;
   PyObject *py_ret;
@@ -1108,7 +1111,7 @@ guppi_python_module_init ()
     Py_DECREF (py_ret);
 }
 
-/****************************************************************************/
+/**********************************************************************/
 
 static double
 guppi_python_safe_apply (PyObject * proc, PyObject * objs)
@@ -1174,7 +1177,7 @@ py_eval_d__d_d (double x, double y, gpointer py_proc)
   return guppi_python_safe_apply ((PyObject *) py_proc, py_args);
 }
 
-/****************************************************************************/
+/**********************************************************************/
 
 GuppiFnWrapper *
 py2fn_d__i (PyObject * proc)
@@ -1208,4 +1211,4 @@ py2fn_d__d_d (PyObject * proc)
   return guppi_fn_wrapper_new_d__d_d (py_eval_d__d_d, (gpointer) proc);
 }
 
-/* $Id: guppi-python.c,v 1.16 2001/01/20 18:59:21 trow Exp $ */
+/* $Id: guppi-python.c,v 1.21 2001/09/08 05:50:00 trow Exp $ */
